// Include the Stepper library
#include <Stepper.h>

// Define number of steps per revolution
const int stepsPerRevolution = 2048;  // for 28BYJ-48 stepper motor

// Initialize steppers on the ULN2003 pins
Stepper stepper1(stepsPerRevolution, 2, 4, 3, 5);  // IN1, IN3, IN2, IN4
Stepper stepper2(stepsPerRevolution, 6, 8, 7, 9);  // IN1, IN3, IN2, IN4
Stepper stepper3(stepsPerRevolution, 10, 12, 11, 13);  // IN1, IN3, IN2, IN4 (new motor)

// Joystick pins
const int VRx = A0;
const int VRy = A1;

// Variables for joystick values
int xValue, yValue;
int motorSpeed = 10;  // Adjust this value to change motor speed

void setup() {
  // Set motor speeds (RPM)
  stepper1.setSpeed(motorSpeed);
  stepper2.setSpeed(motorSpeed);
  stepper3.setSpeed(motorSpeed);
  
  // Initialize joystick pins as inputs
  pinMode(VRx, INPUT);
  pinMode(VRy, INPUT);
}

void loop() {
  // Read joystick values (0-1023)
  xValue = analogRead(VRx);
  yValue = analogRead(VRy);
  
  // Convert joystick values to motor steps
  int xSteps = map(xValue, 0, 1023, -5, 5);
  int ySteps = map(yValue, 0, 1023, -5, 5);
  
  // Move stepper3 based on left-right joystick movement
  if (abs(xSteps) > 1) {
    stepper3.step(-xSteps);
  }
  
  // Move stepper1 and stepper2 in unison based on up-down joystick movement
  if (abs(ySteps) > 1) {
    stepper1.step(-ySteps);
    stepper2.step(ySteps);
  }
  
  // Small delay to prevent the motors from stuttering
  delay(5);
}
